opencl_diagnostics: OpenCL Diagnostic Information

View source: R/bnns.R

opencl_diagnosticsR Documentation

OpenCL Diagnostic Information

Description

This helper function lists the available OpenCL platforms and devices on your system. It is useful for determining the correct opencl_ids to pass to bnns() when using GPU acceleration.

Usage

opencl_diagnostics()

Details

The function first checks if the clinfo system command is available. If not, it falls back to looking for the OpenCL R package to retrieve the platforms and devices.

Value

Invoked for its side effect of printing OpenCL diagnostic information.


bnns documentation built on June 8, 2026, 1:06 a.m.