| plot.bnns | R Documentation |
Generates Markov Chain Monte Carlo (MCMC) trace plots, posterior density plots, Posterior Predictive Checks (PPC), or predicted probability distributions for the fitted model.
## S3 method for class 'bnns'
plot(
x,
type = c("trace", "density", "posterior_predictive", "pred_prob"),
pars = NULL,
...
)
x |
A fitted |
type |
Character string indicating the type of plot.
Options are |
pars |
A character vector of parameter names to include in the plot.
By default, this focuses on the output layer ( |
... |
Additional arguments passed to |
A ggplot object containing the requested diagnostic plots.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.